/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */
#include <memory>                  // for allocator, unique_ptr
#include "ccaosdb.h"               // for caosdb_info_version_info, caosdb_...
#include "gtest/gtest-message.h"   // for Message
#include "gtest/gtest-test-part.h" // for TestPartResult
#include "gtest/gtest_pred_impl.h" // for Test, EXPECT_EQ, SuiteApiResolver

TEST(test_ccaosdb, connection_ssl_authentication_success) {


  caosdb_connection_connection connection;
  caosdb_connection_connection_manager_get_default_connection(&connection);

  caosdb_info_version_info version_info;
  caosdb_connection_get_version_info(&version_info, &connection);

  auto major = caosdb_constants_COMPATIBLE_SERVER_VERSION_MAJOR();
  auto minor = caosdb_constants_COMPATIBLE_SERVER_VERSION_MINOR();
  const auto *const pre_release =
    caosdb_constants_COMPATIBLE_SERVER_VERSION_PRE_RELEASE();

  EXPECT_EQ(major, version_info.major);
  EXPECT_EQ(minor, version_info.minor);
  EXPECT_STREQ(pre_release, version_info.pre_release);
}
